<TeXmacs|1.99.7>

<style|source>

<\body>
  <active*|<\src-title>
    <src-package|french|1.0>

    <\src-purpose>
      A style package for french language support
    </src-purpose>

    <src-copyright|2013|Joris van der Hoeven>

    <\src-license>
      This software falls under the <hlink|GNU general public license,
      version 3 or later|$TEXMACS_PATH/LICENSE>. It comes WITHOUT ANY
      WARRANTY WHATSOEVER. You should have received a copy of the license
      which the software. If not, see <hlink|http://www.gnu.org/licenses/gpl-3.0.html|http://www.gnu.org/licenses/gpl-3.0.html>.
    </src-license>
  </src-title>>

  <assign|language|french>

  \;

  <assign|text-dots-sep|0.25spc>

  <assign|text-dots|<macro|.<text-spc>.<text-spc>.<text-spc>>>
</body>

<\initial>
  <\collection>
    <associate|preamble|true>
  </collection>
</initial>